diff --git a/pgadmin/ctl/ctlSQLBox.cpp b/pgadmin/ctl/ctlSQLBox.cpp
index 969b1c9..c85c37d 100644
--- a/pgadmin/ctl/ctlSQLBox.cpp
+++ b/pgadmin/ctl/ctlSQLBox.cpp
@@ -21,6 +21,7 @@
 #include "ctl/ctlSQLBox.h"
 #include "dlg/dlgFindReplace.h"
 #include "frm/menu.h"
+#include "utils/sysProcess.h"
 
 wxString ctlSQLBox::sqlKeywords;
 
@@ -41,6 +42,7 @@ BEGIN_EVENT_TABLE(ctlSQLBox, wxStyledTextCtrl)
 	EVT_KILL_FOCUS(ctlSQLBox::OnKillFocus)
 	EVT_STC_PAINTED(-1,  ctlSQLBox::OnPositionStc)
 	EVT_STC_MARGINCLICK(-1, ctlSQLBox::OnMarginClick)
+	EVT_END_PROCESS(-1,  ctlSQLBox::OnEndProcess)
 END_EVENT_TABLE()
 
 
@@ -53,6 +55,8 @@ ctlSQLBox::ctlSQLBox()
 	m_dlgFindReplace = 0;
 	m_autoIndent = false;
 	m_autocompDisabled = false;
+	process = 0;
+	processID = 0;
 }
 
 
@@ -63,6 +67,8 @@ ctlSQLBox::ctlSQLBox(wxWindow *parent, wxWindowID id, const wxPoint &pos, const
 	m_database = NULL;
 
 	m_autocompDisabled = false;
+	process = 0;
+	processID = 0;
 
 	Create(parent, id, pos, size, style);
 }
@@ -553,6 +559,108 @@ void ctlSQLBox::UpdateLineNumber()
 	}
 }
 
+void ctlSQLBox::OnEndProcess(wxProcessEvent &ev)
+{
+	if (process)
+	{
+		processErrorOutput = process->ReadErrorStream();
+		processOutput += process->ReadInputStream();
+		processExitCode = ev.GetExitCode();
+		delete process;
+		process = 0;
+		processID = 0;
+	}
+}
+
+wxString ctlSQLBox::ExternalFormat()
+{
+	wxString msg;
+	processOutput = wxEmptyString;
+
+	bool isSelected = true;
+	wxString processInput = GetSelectedText();
+	if (processInput.IsEmpty())
+	{
+		processInput = GetText();
+		isSelected = false;
+	}
+	if (processInput.IsEmpty())
+		return _("Nothing to format.");
+
+	wxString formatCmd = settings->GetExtFormatCmd();
+	if (formatCmd.IsEmpty()) {
+		return _("You need to setup a formatting command");
+	}
+
+	if (process)
+	{
+		delete process;
+		process = NULL;
+		processID = 0;
+	}
+	processOutput = wxEmptyString;
+	processErrorOutput = wxEmptyString;
+	processExitCode = 0;
+
+	process = new sysProcess(this, wxConvUTF8);
+	processID = wxExecute(formatCmd, wxEXEC_ASYNC|wxEXEC_MAKE_GROUP_LEADER, process);
+	if (!processID) {
+		delete process;
+		process = NULL;
+		processID = 0;
+		msg = _("Couldn't run formatting command: ") + formatCmd;
+		return msg;
+	}
+	process->WriteOutputStream(processInput);
+	process->CloseOutput();
+
+	int timeoutMs = 3000;
+	int timeoutStepMs = 100;
+	int i=0;
+	while (process && i * timeoutStepMs < timeoutMs) {
+		wxSafeYield();
+		if (process)
+			processOutput += process->ReadInputStream();
+		wxSafeYield();
+		wxMilliSleep(timeoutStepMs);
+		i++;
+	}
+
+	if (process) {
+		AbortProcess();
+		return _("Formatting command did not respond in 3 seconds");
+	}
+
+	if (processExitCode != 0) {
+		processErrorOutput.Replace(wxT("\n"), wxT(" "));
+		msg = wxString::Format(_("Error %d: "), processExitCode) + processErrorOutput;
+		return msg;
+	} else if (processOutput.Trim().IsEmpty()) {
+		return _("Formatting command error: Output is empty.");
+	}
+
+	if (isSelected)
+		ReplaceSelection(processOutput);
+	else
+		SetText(processOutput);
+
+	return _("Formatting complete.");
+}
+
+void ctlSQLBox::AbortProcess()
+{
+	if (process && processID)
+	{
+#ifdef __WXMSW__
+		// SIGTERM is useless for Windows console apps
+		wxKill(processID, wxSIGKILL, NULL, wxKILL_CHILDREN);
+#else
+		wxKill(processID, wxSIGTERM, NULL, wxKILL_CHILDREN);
+#endif
+		processID = 0;
+	}
+}
+
 void ctlSQLBox::OnPositionStc(wxStyledTextEvent &event)
 {
 	int pos = GetCurrentPos();
@@ -679,6 +787,7 @@ ctlSQLBox::~ctlSQLBox()
 		m_dlgFindReplace->Destroy();
 		m_dlgFindReplace = 0;
 	}
+	AbortProcess();
 }
 
 
diff --git a/pgadmin/frm/frmOptions.cpp b/pgadmin/frm/frmOptions.cpp
index 4b3b1f1..6090925 100644
--- a/pgadmin/frm/frmOptions.cpp
+++ b/pgadmin/frm/frmOptions.cpp
@@ -103,8 +103,9 @@
 #define pickerSlowProcessColour     CTRL_COLOURPICKER("pickerSlowProcessColour")
 #define pickerBlockedProcessColour  CTRL_COLOURPICKER("pickerBlockedProcessColour")
 #define pickerFavouritesFile        CTRL_FILEPICKER("pickerFavouritesFile")
-#define pickerMacrosFile               CTRL_FILEPICKER("pickerMacrosFile")
-#define pickerHistoryFile              CTRL_FILEPICKER("pickerHistoryFile")
+#define pickerMacrosFile            CTRL_FILEPICKER("pickerMacrosFile")
+#define pickerHistoryFile           CTRL_FILEPICKER("pickerHistoryFile")
+#define pickerExtFormatCmd          CTRL_FILEPICKER("pickerExtFormatCmd")
 #define txtHistoryMaxQueries        CTRL_TEXT("txtHistoryMaxQueries")
 #define txtHistoryMaxQuerySize      CTRL_TEXT("txtHistoryMaxQuerySize")
 #define chkSQLUseSystemBackgroundColour  CTRL_CHECKBOX("chkSQLUseSystemBackgroundColour")
@@ -332,6 +333,7 @@ frmOptions::frmOptions(frmMain *parent)
 	pickerFavouritesFile->SetPath(settings->GetFavouritesFile());
 	pickerMacrosFile->SetPath(settings->GetMacrosFile());
 	pickerHistoryFile->SetPath(settings->GetHistoryFile());
+	pickerExtFormatCmd->SetPath(settings->GetExtFormatCmd());
 
 	txtHistoryMaxQueries->SetValue(NumToStr(settings->GetHistoryMaxQueries()));
 	txtHistoryMaxQuerySize->SetValue(NumToStr(settings->GetHistoryMaxQuerySize()));
@@ -784,6 +786,7 @@ void frmOptions::OnOK(wxCommandEvent &ev)
 	settings->SetFavouritesFile(pickerFavouritesFile->GetPath());
 	settings->SetMacrosFile(pickerMacrosFile->GetPath());
 	settings->SetHistoryFile(pickerHistoryFile->GetPath());
+	settings->SetExtFormatCmd(pickerExtFormatCmd->GetPath());
 
 	// Change SQL Syntax colours
 	if (settings->GetSQLBoxUseSystemBackground() != chkSQLUseSystemBackgroundColour->GetValue())
diff --git a/pgadmin/frm/frmQuery.cpp b/pgadmin/frm/frmQuery.cpp
index 23ec45b..eb23b14 100644
--- a/pgadmin/frm/frmQuery.cpp
+++ b/pgadmin/frm/frmQuery.cpp
@@ -148,6 +148,7 @@ BEGIN_EVENT_TABLE(frmQuery, pgFrame)
 	EVT_MENU(MNU_LOWER_CASE,        frmQuery::OnChangeToLowerCase)
 	EVT_MENU(MNU_COMMENT_TEXT,      frmQuery::OnCommentText)
 	EVT_MENU(MNU_UNCOMMENT_TEXT,    frmQuery::OnUncommentText)
+	EVT_MENU(MNU_EXTERNALFORMAT,    frmQuery::OnExternalFormat)
 	EVT_MENU(MNU_LF,                frmQuery::OnSetEOLMode)
 	EVT_MENU(MNU_CRLF,              frmQuery::OnSetEOLMode)
 	EVT_MENU(MNU_CR,                frmQuery::OnSetEOLMode)
@@ -292,6 +293,8 @@ frmQuery::frmQuery(frmMain *form, const wxString &_title, pgConn *_conn, const w
 	formatMenu->Append(MNU_BLOCK_OUTDENT, _("Block &Outdent\tShift-Tab"), _("Outdent the selected block"));
 	formatMenu->Append(MNU_COMMENT_TEXT, _("Co&mment Text\tCtrl-K"), _("Comment out the selected text"));
 	formatMenu->Append(MNU_UNCOMMENT_TEXT, _("Uncomme&nt Text\tCtrl-Shift-K"), _("Uncomment the selected text"));
+	formatMenu->AppendSeparator();
+	formatMenu->Append(MNU_EXTERNALFORMAT, _("External Format\tCtrl-Shift-F"), _("Call external formatting command"));
 	editMenu->AppendSubMenu(formatMenu, _("F&ormat"));
 	editMenu->Append(MNU_LINEENDS, _("&Line ends"), lineEndMenu);
 
@@ -2988,6 +2991,16 @@ void frmQuery::OnUncommentText(wxCommandEvent &event)
 		sqlQuery->BlockComment(true);
 }
 
+void frmQuery::OnExternalFormat(wxCommandEvent &event)
+{
+	if (FindFocus()->GetId() == CTL_SQLQUERY) {
+		wxBusyCursor wait;
+		SetStatusText(_("Running formatting command..."), STATUSPOS_MSGS);
+		SetStatusText(sqlQuery->ExternalFormat(), STATUSPOS_MSGS);
+		sqlQuery->SetFocus(); // could loose focus after running formatting process
+	}
+}
+
 wxBitmap frmQuery::CreateBitmap(const wxColour &colour)
 {
 	const int w = 10, h = 10;
diff --git a/pgadmin/include/ctl/ctlSQLBox.h b/pgadmin/include/ctl/ctlSQLBox.h
index b9f39d7..a683222 100644
--- a/pgadmin/include/ctl/ctlSQLBox.h
+++ b/pgadmin/include/ctl/ctlSQLBox.h
@@ -34,6 +34,8 @@ struct TextToFind
 	struct CharacterRange chrgText;
 };
 
+class sysProcess;
+
 // Class declarations
 class ctlSQLBox : public wxStyledTextCtrl
 {
@@ -67,14 +69,23 @@ public:
 	}
 	bool BlockComment(bool uncomment = false);
 	void UpdateLineNumber();
+	wxString ExternalFormat();
+	void AbortProcess();
 
 	CharacterRange RegexFindText(int minPos, int maxPos, const wxString &text);
 
 	DECLARE_DYNAMIC_CLASS(ctlSQLBox)
 	DECLARE_EVENT_TABLE()
 
-private:
+protected:
+	void OnEndProcess(wxProcessEvent &ev);
 
+	sysProcess *process;
+	long processID;
+	wxString processOutput, processErrorOutput;
+	int processExitCode;
+
+private:
 	void OnPositionStc(wxStyledTextEvent &event);
 	void OnMarginClick(wxStyledTextEvent &event);
 
diff --git a/pgadmin/include/frm/frmQuery.h b/pgadmin/include/frm/frmQuery.h
index c698370..6624607 100644
--- a/pgadmin/include/frm/frmQuery.h
+++ b/pgadmin/include/frm/frmQuery.h
@@ -228,6 +228,7 @@ private:
 	void OnChangeToLowerCase(wxCommandEvent &event);
 	void OnCommentText(wxCommandEvent &event);
 	void OnUncommentText(wxCommandEvent &event);
+	void OnExternalFormat(wxCommandEvent &event);
 
 	void OnDeleteCurrent(wxCommandEvent &event);
 	void OnDeleteAll(wxCommandEvent &event);
diff --git a/pgadmin/include/frm/menu.h b/pgadmin/include/frm/menu.h
index fb20b60..c4df579 100644
--- a/pgadmin/include/frm/menu.h
+++ b/pgadmin/include/frm/menu.h
@@ -101,6 +101,7 @@ enum
 	MNU_BLOCK_OUTDENT,
 	MNU_COMMENT_TEXT,
 	MNU_UNCOMMENT_TEXT,
+	MNU_EXTERNALFORMAT,
 
 	MNU_PLUGINBUTTONLIST,
 
diff --git a/pgadmin/include/utils/sysProcess.h b/pgadmin/include/utils/sysProcess.h
index 75d482d..2a1e926 100644
--- a/pgadmin/include/utils/sysProcess.h
+++ b/pgadmin/include/utils/sysProcess.h
@@ -14,22 +14,25 @@
 
 #include <wx/wx.h>
 #include "wx/process.h"
+#include <wx/txtstrm.h>
 
 class sysProcess : public wxProcess
 {
 public:
-	sysProcess(wxEvtHandler *evh);
+	sysProcess(wxEvtHandler *evh, wxMBConv &conv = wxConvLibc);
 
 	bool Run(const wxString &exec);
 	void Abort();
 	void SetEnvironment(const wxArrayString &environment);
 	wxString ReadInputStream();
 	wxString ReadErrorStream();
+	void WriteOutputStream(const wxString &out);
 
-	static sysProcess *Create(const wxString &exec, wxEvtHandler *evh = 0, wxArrayString *env = 0);
+	static sysProcess *Create(const wxString &exec, wxEvtHandler *evh = 0, wxArrayString *env = 0, wxMBConv &conv = wxConvLibc);
 
 private:
 	int pid;
+	wxMBConv& m_conv;
 	void OnTerminate(int pid, int status) const;
 	wxString ReadStream(wxInputStream *input);
 };
diff --git a/pgadmin/include/utils/sysSettings.h b/pgadmin/include/utils/sysSettings.h
index eb11213..1c170c5 100644
--- a/pgadmin/include/utils/sysSettings.h
+++ b/pgadmin/include/utils/sysSettings.h
@@ -440,6 +440,11 @@ public:
 	{
 		Write(wxT("MacrosFile"), newval);
 	}
+	wxString GetExtFormatCmd();
+	void SetExtFormatCmd(const wxString &newval)
+	{
+		Write(wxT("ExtFormatCmd"), newval);
+	}
 	wxString GetHistoryFile();
 	void SetHistoryFile(const wxString &newval)
 	{
diff --git a/pgadmin/ui/frmOptions.xrc b/pgadmin/ui/frmOptions.xrc
index a57b0ce..5147428 100644
--- a/pgadmin/ui/frmOptions.xrc
+++ b/pgadmin/ui/frmOptions.xrc
@@ -399,16 +399,16 @@
               <border>4</border>
             </object>
             <object class="sizeritem">
-			  <object class="wxPanel" name="pnlQueryToolEditor">
-				  <hidden>1</hidden>
+              <object class="wxPanel" name="pnlQueryToolEditor">
+                <hidden>1</hidden>
                 <object class="wxFlexGridSizer">
                   <cols>2</cols>
                   <vgap>5</vgap>
                   <hgap>5</hgap>
                   <growablecols>1</growablecols>
-                <object class="sizeritem">
-                  <object class="wxStaticText" name="stSqlFont">
-                    <label>Font</label>
+                  <object class="sizeritem">
+                    <object class="wxStaticText" name="stSqlFont">
+                      <label>Font</label>
                   </object>
                   <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
                   <border>4</border>
@@ -502,7 +502,24 @@
                     </object>
                     <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
                     <border>4</border>
-                  </object>                  
+                  </object>
+                  <object class="sizeritem">
+                    <object class="wxStaticText" name="stExtFormatCmd">
+                      <label>External formatting utlity</label>
+                    </object>
+                    <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                    <border>4</border>
+                  </object>
+                  <object class="sizeritem">
+                    <object class="wxFilePickerCtrl" name="pickerExtFormatCmd">
+                      <message>Select utility to format text</message>
+                      <wildcard>*</wildcard>
+                      <style>wxFLP_OPEN|wxFLP_USE_TEXTCTRL</style>
+                      <tooltip>A command line utility which reads STDIN and directs output to STDOUT.</tooltip>
+                    </object>
+                    <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                    <border>4</border>
+                  </object>
                 </object>
               </object>
               <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
@@ -1212,8 +1229,8 @@
               <border>4</border>
             </object>
             <object class="sizeritem">
-			  <object class="wxPanel" name="pnlMiscLogging">
-				  <hidden>1</hidden>
+              <object class="wxPanel" name="pnlMiscLogging">
+                <hidden>1</hidden>
                 <object class="wxFlexGridSizer">
                   <cols>1</cols>
                   <vgap>5</vgap>
diff --git a/pgadmin/ui/xrcDialogs.cpp b/pgadmin/ui/xrcDialogs.cpp
index f6673a9..6e15a1d 100644
--- a/pgadmin/ui/xrcDialogs.cpp
+++ b/pgadmin/ui/xrcDialogs.cpp
@@ -35563,7 +35563,7 @@ static unsigned char xml_res_file_77[] = {
 47,111,98,106,101,99,116,62,10,60,47,114,101,115,111,117,114,99,101,62,
 10};
 
-static size_t xml_res_size_78 = 66776;
+static size_t xml_res_size_78 = 67770;
 static unsigned char xml_res_file_78[] = {
 60,63,120,109,108,32,118,101,114,115,105,111,110,61,34,49,46,48,34,32,101,
 110,99,111,100,105,110,103,61,34,73,83,79,45,56,56,53,57,45,49,34,63,62,
@@ -36714,87 +36714,113 @@ static unsigned char xml_res_file_78[] = {
 10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
 98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,
 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,
-99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,
-111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,
-65,76,73,71,78,95,67,69,78,84,69,82,95,86,69,82,84,73,67,65,76,124,119,
-120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,
-108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,
-111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,
-115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
-97,115,115,61,34,119,120,80,97,110,101,108,34,32,110,97,109,101,61,34,112,
-110,108,81,117,101,114,121,84,111,111,108,67,111,108,111,117,114,115,34,
-62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,104,105,
-100,100,101,110,62,49,60,47,104,105,100,100,101,110,62,10,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
-97,115,115,61,34,119,120,70,108,101,120,71,114,105,100,83,105,122,101,114,
-34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
-99,111,108,115,62,49,60,47,99,111,108,115,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,60,118,103,97,112,62,53,60,47,118,103,
-97,112,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-60,104,103,97,112,62,53,60,47,104,103,97,112,62,10,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,60,103,114,111,119,97,98,108,101,
-99,111,108,115,62,48,60,47,103,114,111,119,97,98,108,101,99,111,108,115,
-62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,
-98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,
-101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,
-83,116,97,116,105,99,66,111,120,83,105,122,101,114,34,62,10,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,
-101,108,62,70,111,114,101,103,114,111,117,110,100,47,66,97,99,107,103,114,
-111,117,110,100,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,114,105,101,110,116,
-62,119,120,86,69,82,84,73,67,65,76,60,47,111,114,105,101,110,116,62,10,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
 60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,
 105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,
-115,61,34,119,120,70,108,101,120,71,114,105,100,83,105,122,101,114,34,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,60,99,111,108,115,62,51,60,47,99,111,108,115,62,10,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,118,103,97,112,62,52,60,47,118,103,97,112,62,10,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
-104,103,97,112,62,52,60,47,104,103,97,112,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,103,114,
-111,119,97,98,108,101,99,111,108,115,62,48,44,49,60,47,103,114,111,119,
-97,98,108,101,99,111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,
-32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
 32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,
-120,67,104,101,99,107,66,111,120,34,32,110,97,109,101,61,34,99,104,107,
-83,81,76,85,115,101,83,121,115,116,101,109,66,97,99,107,103,114,111,117,
-110,100,67,111,108,111,117,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,
-98,101,108,62,85,115,101,32,115,121,115,116,101,109,32,98,97,99,107,103,
-114,111,117,110,100,32,99,111,108,111,114,60,47,108,97,98,101,108,62,10,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,60,115,116,121,108,101,47,62,10,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,
-62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,
-69,82,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,
-70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+120,83,116,97,116,105,99,84,101,120,116,34,32,110,97,109,101,61,34,115,
+116,69,120,116,70,111,114,109,97,116,67,109,100,34,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,
+108,62,69,120,116,101,114,110,97,108,32,102,111,114,109,97,116,116,105,
+110,103,32,117,116,108,105,116,121,60,47,108,97,98,101,108,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,
+106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,69,78,
+84,69,82,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,
+69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,
+100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
+106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,
+109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,70,105,
+108,101,80,105,99,107,101,114,67,116,114,108,34,32,110,97,109,101,61,34,
+112,105,99,107,101,114,69,120,116,70,111,114,109,97,116,67,109,100,34,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,60,109,101,115,115,97,103,101,62,83,101,108,101,99,116,32,117,116,105,
+108,105,116,121,32,116,111,32,102,111,114,109,97,116,32,116,101,120,116,
+60,47,109,101,115,115,97,103,101,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,119,105,108,100,99,97,114,100,
+62,42,60,47,119,105,108,100,99,97,114,100,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,116,121,108,101,
+62,119,120,70,76,80,95,79,80,69,78,124,119,120,70,76,80,95,85,83,69,95,
+84,69,88,84,67,84,82,76,60,47,115,116,121,108,101,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,116,111,111,
+108,116,105,112,62,65,32,99,111,109,109,97,110,100,32,108,105,110,101,32,
+117,116,105,108,105,116,121,32,119,104,105,99,104,32,114,101,97,100,115,
+32,83,84,68,73,78,32,97,110,100,32,100,105,114,101,99,116,115,32,111,117,
+116,112,117,116,32,116,111,32,83,84,68,79,85,84,46,60,47,116,111,111,108,
+116,105,112,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
 32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
-101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,
-34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,
+88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,69,82,95,86,69,
+82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,
+120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,
+60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,
+116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,
+103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,
+84,69,82,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,
+69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,
+60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,
+101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,80,
+97,110,101,108,34,32,110,97,109,101,61,34,112,110,108,81,117,101,114,121,
+84,111,111,108,67,111,108,111,117,114,115,34,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,104,105,100,100,101,110,62,49,60,47,
+104,105,100,100,101,110,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,
+70,108,101,120,71,114,105,100,83,105,122,101,114,34,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,99,111,108,115,62,49,60,
+47,99,111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,118,103,97,112,62,53,60,47,118,103,97,112,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,104,103,97,112,62,
+53,60,47,104,103,97,112,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,103,114,111,119,97,98,108,101,99,111,108,115,62,48,
+60,47,103,114,111,119,97,98,108,101,99,111,108,115,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,
+99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
+106,101,99,116,32,99,108,97,115,115,61,34,119,120,83,116,97,116,105,99,
+66,111,120,83,105,122,101,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,70,111,114,
+101,103,114,111,117,110,100,47,66,97,99,107,103,114,111,117,110,100,60,
+47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,111,114,105,101,110,116,62,119,120,86,69,
+82,84,73,67,65,76,60,47,111,114,105,101,110,116,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,
+99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,
+70,108,101,120,71,114,105,100,83,105,122,101,114,34,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
+99,111,108,115,62,51,60,47,99,111,108,115,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,118,103,
+97,112,62,52,60,47,118,103,97,112,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,104,103,97,112,62,
+52,60,47,104,103,97,112,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,103,114,111,119,97,98,108,
+101,99,111,108,115,62,48,44,49,60,47,103,114,111,119,97,98,108,101,99,111,
+108,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
 32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,
-61,34,119,120,83,116,97,116,105,99,84,101,120,116,34,32,110,97,109,101,
-61,34,115,116,83,81,76,67,117,115,116,111,109,66,97,99,107,103,114,111,
-117,110,100,67,111,108,111,117,114,34,62,10,32,32,32,32,32,32,32,32,32,
+61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,
 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
-108,97,98,101,108,62,67,117,115,116,111,109,32,98,97,99,107,103,114,111,
-117,110,100,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,
+111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,67,104,101,99,
+107,66,111,120,34,32,110,97,109,101,61,34,99,104,107,83,81,76,85,115,101,
+83,121,115,116,101,109,66,97,99,107,103,114,111,117,110,100,67,111,108,
+111,117,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,85,
+115,101,32,115,121,115,116,101,109,32,98,97,99,107,103,114,111,117,110,
+100,32,99,111,108,111,114,60,47,108,97,98,101,108,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,60,115,116,121,108,101,47,62,10,32,32,32,32,32,32,32,32,32,32,
 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,
 106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
 32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,
@@ -36808,12 +36834,54 @@ static unsigned char xml_res_file_78[] = {
 32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,
 108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,
 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,99,116,
-108,67,111,108,111,117,114,80,105,99,107,101,114,34,32,110,97,109,101,61,
-34,112,105,99,107,101,114,83,81,76,66,97,99,107,103,114,111,117,110,100,
+32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,
+83,116,97,116,105,99,84,101,120,116,34,32,110,97,109,101,61,34,115,116,
+83,81,76,67,117,115,116,111,109,66,97,99,107,103,114,111,117,110,100,67,
+111,108,111,117,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,
+108,62,67,117,115,116,111,109,32,98,97,99,107,103,114,111,117,110,100,60,
+47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,
+124,119,120,65,76,73,71,78,95,67,69,78,84,69,82,95,86,69,82,84,73,67,65,
+76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,
+84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,
+62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
+101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,
+115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,99,116,108,67,111,108,
+111,117,114,80,105,99,107,101,114,34,32,110,97,109,101,61,34,112,105,99,
+107,101,114,83,81,76,66,97,99,107,103,114,111,117,110,100,67,111,108,111,
+117,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,105,122,101,62,55,48,44,
+49,50,100,60,47,115,105,122,101,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
+101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,
+80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,69,82,95,86,69,82,
+84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,
+82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,
+100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,
+111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
+97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,67,
+104,101,99,107,66,111,120,34,32,110,97,109,101,61,34,99,104,107,83,81,76,
+85,115,101,83,121,115,116,101,109,70,111,114,101,103,114,111,117,110,100,
 67,111,108,111,117,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,105,122,
-101,62,55,48,44,49,50,100,60,47,115,105,122,101,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,
+108,62,85,115,101,32,115,121,115,116,101,109,32,102,111,114,101,103,114,
+111,117,110,100,32,99,111,108,111,114,60,47,108,97,98,101,108,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,115,116,121,108,101,47,62,10,32,32,32,32,32,32,
 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
 60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,
@@ -36828,50 +36896,28 @@ static unsigned char xml_res_file_78[] = {
 99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,
 62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
 32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,
-34,119,120,67,104,101,99,107,66,111,120,34,32,110,97,109,101,61,34,99,104,
-107,83,81,76,85,115,101,83,121,115,116,101,109,70,111,114,101,103,114,111,
-117,110,100,67,111,108,111,117,114,34,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
-108,97,98,101,108,62,85,115,101,32,115,121,115,116,101,109,32,102,111,114,
-101,103,114,111,117,110,100,32,99,111,108,111,114,60,47,108,97,98,101,108,
-62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,60,115,116,121,108,101,47,62,10,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,
-97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,
-78,84,69,82,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,
-76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,
-62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
-106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,
-109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,
-115,61,34,119,120,83,116,97,116,105,99,84,101,120,116,34,32,110,97,109,
-101,61,34,115,116,83,81,76,67,117,115,116,111,109,70,111,114,101,103,114,
-111,117,110,100,67,111,108,111,117,114,34,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-60,108,97,98,101,108,62,67,117,115,116,111,109,32,102,111,114,101,103,114,
-111,117,110,100,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,
-98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,
-69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,69,82,95,86,
-69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,
-120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,
-114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
-47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,
-108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,
+34,119,120,83,116,97,116,105,99,84,101,120,116,34,32,110,97,109,101,61,
+34,115,116,83,81,76,67,117,115,116,111,109,70,111,114,101,103,114,111,117,
+110,100,67,111,108,111,117,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,
+98,101,108,62,67,117,115,116,111,109,32,102,111,114,101,103,114,111,117,
+110,100,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
+101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,
+80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,69,82,95,86,69,82,
+84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,
+82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,
+100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,
+111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
+97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,
 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,99,116,
-108,67,111,108,111,117,114,80,105,99,107,101,114,34,32,110,97,109,101,61,
-34,112,105,99,107,101,114,83,81,76,70,111,114,101,103,114,111,117,110,100,
+32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,99,116,108,
+67,111,108,111,117,114,80,105,99,107,101,114,34,32,110,97,109,101,61,34,
+112,105,99,107,101,114,83,81,76,70,111,114,101,103,114,111,117,110,100,
 67,111,108,111,117,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,105,122,
 101,62,55,48,44,49,50,100,60,47,115,105,122,101,62,10,32,32,32,32,32,32,
@@ -39670,168 +39716,168 @@ void InitXmlResource()
         else wxFileSystem::AddHandler(new wxMemoryFSHandler);
     }
 
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._ddPrecisionScaleDialog.xrc"), xml_res_file_0, xml_res_size_0, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._ddTableNameDialog.xrc"), xml_res_file_1, xml_res_size_1, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgAddFavourite.xrc"), xml_res_file_2, xml_res_size_2, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgAggregate.xrc"), xml_res_file_3, xml_res_size_3, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgCast.xrc"), xml_res_file_4, xml_res_size_4, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgCheck.xrc"), xml_res_file_5, xml_res_size_5, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgCollation.xrc"), xml_res_file_6, xml_res_size_6, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgColumn.xrc"), xml_res_file_7, xml_res_size_7, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgConnect.xrc"), xml_res_file_8, xml_res_size_8, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgConversion.xrc"), xml_res_file_9, xml_res_size_9, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgDatabase.xrc"), xml_res_file_10, xml_res_size_10, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgDirectDbg.xrc"), xml_res_file_11, xml_res_size_11, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgDomain.xrc"), xml_res_file_12, xml_res_size_12, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgEditGridOptions.xrc"), xml_res_file_13, xml_res_size_13, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgEventTrigger.xrc"), xml_res_file_14, xml_res_size_14, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgExtTable.xrc"), xml_res_file_15, xml_res_size_15, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgExtension.xrc"), xml_res_file_16, xml_res_size_16, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgFindReplace.xrc"), xml_res_file_17, xml_res_size_17, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgForeignDataWrapper.xrc"), xml_res_file_18, xml_res_size_18, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgForeignKey.xrc"), xml_res_file_19, xml_res_size_19, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgForeignServer.xrc"), xml_res_file_20, xml_res_size_20, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgForeignTable.xrc"), xml_res_file_21, xml_res_size_21, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgFunction.xrc"), xml_res_file_22, xml_res_size_22, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgGroup.xrc"), xml_res_file_23, xml_res_size_23, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgHbaConfig.xrc"), xml_res_file_24, xml_res_size_24, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgIndex.xrc"), xml_res_file_25, xml_res_size_25, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgIndexConstraint.xrc"), xml_res_file_26, xml_res_size_26, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgJob.xrc"), xml_res_file_27, xml_res_size_27, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgLanguage.xrc"), xml_res_file_28, xml_res_size_28, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgMainConfig.xrc"), xml_res_file_29, xml_res_size_29, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgManageFavourites.xrc"), xml_res_file_30, xml_res_size_30, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgManageMacros.xrc"), xml_res_file_31, xml_res_size_31, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgMoveTablespace.xrc"), xml_res_file_32, xml_res_size_32, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgOperator.xrc"), xml_res_file_33, xml_res_size_33, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgPackage.xrc"), xml_res_file_34, xml_res_size_34, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgPgpassConfig.xrc"), xml_res_file_35, xml_res_size_35, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgReassignDropOwned.xrc"), xml_res_file_36, xml_res_size_36, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgRepCluster.xrc"), xml_res_file_37, xml_res_size_37, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgRepClusterUpgrade.xrc"), xml_res_file_38, xml_res_size_38, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgRepListen.xrc"), xml_res_file_39, xml_res_size_39, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgRepNode.xrc"), xml_res_file_40, xml_res_size_40, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgRepPath.xrc"), xml_res_file_41, xml_res_size_41, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgRepSequence.xrc"), xml_res_file_42, xml_res_size_42, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgRepSet.xrc"), xml_res_file_43, xml_res_size_43, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgRepSetMerge.xrc"), xml_res_file_44, xml_res_size_44, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgRepSetMove.xrc"), xml_res_file_45, xml_res_size_45, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgRepSubscription.xrc"), xml_res_file_46, xml_res_size_46, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgRepTable.xrc"), xml_res_file_47, xml_res_size_47, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgResourceGroup.xrc"), xml_res_file_48, xml_res_size_48, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgRole.xrc"), xml_res_file_49, xml_res_size_49, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgRule.xrc"), xml_res_file_50, xml_res_size_50, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgSchedule.xrc"), xml_res_file_51, xml_res_size_51, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgSchema.xrc"), xml_res_file_52, xml_res_size_52, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgSearchObject.xrc"), xml_res_file_53, xml_res_size_53, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgSelectConnection.xrc"), xml_res_file_54, xml_res_size_54, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgSequence.xrc"), xml_res_file_55, xml_res_size_55, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgServer.xrc"), xml_res_file_56, xml_res_size_56, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgStep.xrc"), xml_res_file_57, xml_res_size_57, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgSynonym.xrc"), xml_res_file_58, xml_res_size_58, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgTable.xrc"), xml_res_file_59, xml_res_size_59, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgTablespace.xrc"), xml_res_file_60, xml_res_size_60, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgTextSearchConfiguration.xrc"), xml_res_file_61, xml_res_size_61, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgTextSearchDictionary.xrc"), xml_res_file_62, xml_res_size_62, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgTextSearchParser.xrc"), xml_res_file_63, xml_res_size_63, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgTextSearchTemplate.xrc"), xml_res_file_64, xml_res_size_64, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgTrigger.xrc"), xml_res_file_65, xml_res_size_65, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgType.xrc"), xml_res_file_66, xml_res_size_66, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgUser.xrc"), xml_res_file_67, xml_res_size_67, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgUserMapping.xrc"), xml_res_file_68, xml_res_size_68, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgView.xrc"), xml_res_file_69, xml_res_size_69, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._frmBackup.xrc"), xml_res_file_70, xml_res_size_70, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._frmBackupGlobals.xrc"), xml_res_file_71, xml_res_size_71, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._frmBackupServer.xrc"), xml_res_file_72, xml_res_size_72, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._frmExport.xrc"), xml_res_file_73, xml_res_size_73, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._frmGrantWizard.xrc"), xml_res_file_74, xml_res_size_74, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._frmHint.xrc"), xml_res_file_75, xml_res_size_75, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._frmImport.xrc"), xml_res_file_76, xml_res_size_76, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._frmMaintenance.xrc"), xml_res_file_77, xml_res_size_77, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._frmOptions.xrc"), xml_res_file_78, xml_res_size_78, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._frmPassword.xrc"), xml_res_file_79, xml_res_size_79, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._frmReport.xrc"), xml_res_file_80, xml_res_size_80, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._frmRestore.xrc"), xml_res_file_81, xml_res_size_81, wxT("text/xml"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._ddPrecisionScaleDialog.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._ddTableNameDialog.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgAddFavourite.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgAggregate.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgCast.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgCheck.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgCollation.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgColumn.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgConnect.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgConversion.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgDatabase.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgDirectDbg.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgDomain.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgEditGridOptions.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgEventTrigger.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgExtTable.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgExtension.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgFindReplace.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgForeignDataWrapper.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgForeignKey.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgForeignServer.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgForeignTable.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgFunction.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgGroup.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgHbaConfig.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgIndex.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgIndexConstraint.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgJob.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgLanguage.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgMainConfig.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgManageFavourites.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgManageMacros.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgMoveTablespace.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgOperator.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgPackage.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgPgpassConfig.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgReassignDropOwned.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgRepCluster.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgRepClusterUpgrade.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgRepListen.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgRepNode.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgRepPath.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgRepSequence.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgRepSet.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgRepSetMerge.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgRepSetMove.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgRepSubscription.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgRepTable.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgResourceGroup.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgRole.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgRule.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgSchedule.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgSchema.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgSearchObject.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgSelectConnection.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgSequence.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgServer.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgStep.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgSynonym.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgTable.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgTablespace.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgTextSearchConfiguration.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgTextSearchDictionary.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgTextSearchParser.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgTextSearchTemplate.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgTrigger.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgType.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgUser.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgUserMapping.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgView.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._frmBackup.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._frmBackupGlobals.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._frmBackupServer.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._frmExport.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._frmGrantWizard.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._frmHint.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._frmImport.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._frmMaintenance.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._frmOptions.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._frmPassword.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._frmReport.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._frmRestore.xrc"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_ddPrecisionScaleDialog.xrc"), xml_res_file_0, xml_res_size_0, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_ddTableNameDialog.xrc"), xml_res_file_1, xml_res_size_1, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgAddFavourite.xrc"), xml_res_file_2, xml_res_size_2, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgAggregate.xrc"), xml_res_file_3, xml_res_size_3, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgCast.xrc"), xml_res_file_4, xml_res_size_4, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgCheck.xrc"), xml_res_file_5, xml_res_size_5, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgCollation.xrc"), xml_res_file_6, xml_res_size_6, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgColumn.xrc"), xml_res_file_7, xml_res_size_7, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgConnect.xrc"), xml_res_file_8, xml_res_size_8, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgConversion.xrc"), xml_res_file_9, xml_res_size_9, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgDatabase.xrc"), xml_res_file_10, xml_res_size_10, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgDirectDbg.xrc"), xml_res_file_11, xml_res_size_11, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgDomain.xrc"), xml_res_file_12, xml_res_size_12, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgEditGridOptions.xrc"), xml_res_file_13, xml_res_size_13, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgEventTrigger.xrc"), xml_res_file_14, xml_res_size_14, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgExtTable.xrc"), xml_res_file_15, xml_res_size_15, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgExtension.xrc"), xml_res_file_16, xml_res_size_16, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgFindReplace.xrc"), xml_res_file_17, xml_res_size_17, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgForeignDataWrapper.xrc"), xml_res_file_18, xml_res_size_18, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgForeignKey.xrc"), xml_res_file_19, xml_res_size_19, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgForeignServer.xrc"), xml_res_file_20, xml_res_size_20, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgForeignTable.xrc"), xml_res_file_21, xml_res_size_21, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgFunction.xrc"), xml_res_file_22, xml_res_size_22, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgGroup.xrc"), xml_res_file_23, xml_res_size_23, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgHbaConfig.xrc"), xml_res_file_24, xml_res_size_24, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgIndex.xrc"), xml_res_file_25, xml_res_size_25, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgIndexConstraint.xrc"), xml_res_file_26, xml_res_size_26, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgJob.xrc"), xml_res_file_27, xml_res_size_27, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgLanguage.xrc"), xml_res_file_28, xml_res_size_28, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgMainConfig.xrc"), xml_res_file_29, xml_res_size_29, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgManageFavourites.xrc"), xml_res_file_30, xml_res_size_30, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgManageMacros.xrc"), xml_res_file_31, xml_res_size_31, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgMoveTablespace.xrc"), xml_res_file_32, xml_res_size_32, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgOperator.xrc"), xml_res_file_33, xml_res_size_33, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgPackage.xrc"), xml_res_file_34, xml_res_size_34, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgPgpassConfig.xrc"), xml_res_file_35, xml_res_size_35, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgReassignDropOwned.xrc"), xml_res_file_36, xml_res_size_36, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepCluster.xrc"), xml_res_file_37, xml_res_size_37, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepClusterUpgrade.xrc"), xml_res_file_38, xml_res_size_38, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepListen.xrc"), xml_res_file_39, xml_res_size_39, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepNode.xrc"), xml_res_file_40, xml_res_size_40, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepPath.xrc"), xml_res_file_41, xml_res_size_41, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepSequence.xrc"), xml_res_file_42, xml_res_size_42, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepSet.xrc"), xml_res_file_43, xml_res_size_43, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepSetMerge.xrc"), xml_res_file_44, xml_res_size_44, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepSetMove.xrc"), xml_res_file_45, xml_res_size_45, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepSubscription.xrc"), xml_res_file_46, xml_res_size_46, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepTable.xrc"), xml_res_file_47, xml_res_size_47, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgResourceGroup.xrc"), xml_res_file_48, xml_res_size_48, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRole.xrc"), xml_res_file_49, xml_res_size_49, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRule.xrc"), xml_res_file_50, xml_res_size_50, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgSchedule.xrc"), xml_res_file_51, xml_res_size_51, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgSchema.xrc"), xml_res_file_52, xml_res_size_52, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgSearchObject.xrc"), xml_res_file_53, xml_res_size_53, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgSelectConnection.xrc"), xml_res_file_54, xml_res_size_54, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgSequence.xrc"), xml_res_file_55, xml_res_size_55, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgServer.xrc"), xml_res_file_56, xml_res_size_56, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgStep.xrc"), xml_res_file_57, xml_res_size_57, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgSynonym.xrc"), xml_res_file_58, xml_res_size_58, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTable.xrc"), xml_res_file_59, xml_res_size_59, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTablespace.xrc"), xml_res_file_60, xml_res_size_60, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTextSearchConfiguration.xrc"), xml_res_file_61, xml_res_size_61, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTextSearchDictionary.xrc"), xml_res_file_62, xml_res_size_62, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTextSearchParser.xrc"), xml_res_file_63, xml_res_size_63, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTextSearchTemplate.xrc"), xml_res_file_64, xml_res_size_64, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTrigger.xrc"), xml_res_file_65, xml_res_size_65, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgType.xrc"), xml_res_file_66, xml_res_size_66, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgUser.xrc"), xml_res_file_67, xml_res_size_67, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgUserMapping.xrc"), xml_res_file_68, xml_res_size_68, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgView.xrc"), xml_res_file_69, xml_res_size_69, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmBackup.xrc"), xml_res_file_70, xml_res_size_70, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmBackupGlobals.xrc"), xml_res_file_71, xml_res_size_71, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmBackupServer.xrc"), xml_res_file_72, xml_res_size_72, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmExport.xrc"), xml_res_file_73, xml_res_size_73, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmGrantWizard.xrc"), xml_res_file_74, xml_res_size_74, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmHint.xrc"), xml_res_file_75, xml_res_size_75, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmImport.xrc"), xml_res_file_76, xml_res_size_76, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmMaintenance.xrc"), xml_res_file_77, xml_res_size_77, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmOptions.xrc"), xml_res_file_78, xml_res_size_78, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmPassword.xrc"), xml_res_file_79, xml_res_size_79, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmReport.xrc"), xml_res_file_80, xml_res_size_80, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmRestore.xrc"), xml_res_file_81, xml_res_size_81, wxT("text/xml"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_ddPrecisionScaleDialog.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_ddTableNameDialog.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgAddFavourite.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgAggregate.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgCast.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgCheck.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgCollation.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgColumn.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgConnect.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgConversion.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgDatabase.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgDirectDbg.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgDomain.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgEditGridOptions.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgEventTrigger.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgExtTable.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgExtension.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgFindReplace.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgForeignDataWrapper.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgForeignKey.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgForeignServer.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgForeignTable.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgFunction.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgGroup.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgHbaConfig.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgIndex.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgIndexConstraint.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgJob.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgLanguage.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgMainConfig.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgManageFavourites.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgManageMacros.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgMoveTablespace.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgOperator.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgPackage.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgPgpassConfig.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgReassignDropOwned.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepCluster.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepClusterUpgrade.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepListen.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepNode.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepPath.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepSequence.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepSet.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepSetMerge.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepSetMove.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepSubscription.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepTable.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgResourceGroup.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRole.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRule.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgSchedule.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgSchema.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgSearchObject.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgSelectConnection.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgSequence.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgServer.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgStep.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgSynonym.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTable.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTablespace.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTextSearchConfiguration.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTextSearchDictionary.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTextSearchParser.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTextSearchTemplate.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTrigger.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgType.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgUser.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgUserMapping.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgView.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmBackup.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmBackupGlobals.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmBackupServer.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmExport.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmGrantWizard.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmHint.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmImport.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmMaintenance.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmOptions.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmPassword.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmReport.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmRestore.xrc"));
 }
diff --git a/pgadmin/utils/sysProcess.cpp b/pgadmin/utils/sysProcess.cpp
index baaab02..ce9672a 100644
--- a/pgadmin/utils/sysProcess.cpp
+++ b/pgadmin/utils/sysProcess.cpp
@@ -19,17 +19,17 @@
 #include "utils/sysProcess.h"
 
 
-sysProcess::sysProcess(wxEvtHandler *evh)
-	: wxProcess(evh)
+sysProcess::sysProcess(wxEvtHandler *evh, wxMBConv &conv)
+	: wxProcess(evh), m_conv(conv)
 {
 	pid = 0;
 	Redirect();
 }
 
 
-sysProcess *sysProcess::Create(const wxString &exec, wxEvtHandler *evh, wxArrayString *env)
+sysProcess *sysProcess::Create(const wxString &exec, wxEvtHandler *evh, wxArrayString *env, wxMBConv &conv)
 {
-	sysProcess *proc = new sysProcess(evh);
+	sysProcess *proc = new sysProcess(evh, conv);
 	if (env)
 		proc->SetEnvironment(*env);
 
@@ -45,7 +45,6 @@ sysProcess *sysProcess::Create(const wxString &exec, wxEvtHandler *evh, wxArrayS
 bool sysProcess::Run(const wxString &exec)
 {
 	pid = wxExecute(exec, wxEXEC_ASYNC, this);
-
 	return (pid != 0);
 }
 
@@ -83,6 +82,14 @@ wxString sysProcess::ReadErrorStream()
 	return wxEmptyString;
 }
 
+void sysProcess::WriteOutputStream(const wxString &out)
+{
+	// With wxEOL_DOS (=wxEOL_NATIVE in Windows) WriteString() will turn each '\n'
+	//   into "\r\n", thus making "\r\n" a wrong "\r\r\n".
+	// With wxEOL_UNIX it passes EOL characters as-is, which is preferable.
+	wxTextOutputStream tos(*GetOutputStream(), wxEOL_UNIX);
+	tos.WriteString(out);
+}
 
 wxString sysProcess::ReadStream(wxInputStream *input)
 {
@@ -97,7 +104,7 @@ wxString sysProcess::ReadStream(wxInputStream *input)
 		if (size)
 		{
 			buffer[size] = 0;
-			str.Append(wxString::Format(wxT("%s"), wxString(buffer, wxConvLibc).c_str()));
+			str.Append(wxString::Format(wxT("%s"), wxString(buffer, m_conv).c_str()));
 		}
 	}
 	return str;
diff --git a/pgadmin/utils/sysSettings.cpp b/pgadmin/utils/sysSettings.cpp
index e9f270c..014248c 100644
--- a/pgadmin/utils/sysSettings.cpp
+++ b/pgadmin/utils/sysSettings.cpp
@@ -868,3 +868,10 @@ wxString sysSettings::GetHistoryFile()
 	return s;
 }
 
+wxString sysSettings::GetExtFormatCmd()
+{
+	wxString s; //, tmp;
+
+	Read(wxT("ExtFormatCmd"), &s, wxEmptyString);
+	return s;
+}
